@@ -1,4 +1,4 @@
-from alsaaudio import Mixer
+from alsaaudio import Mixer, ALSAAudioError
 
 from i3pystatus import IntervalModule
 
@@ -32,9 +32,15 @@ class ALSA(IntervalModule):
     channel = 0
 
     alsamixer = None
+    has_mute = True
 
     def init(self):
         self.create_mixer()
+        try:
+            self.alsamixer.getmute()
+        except ALSAAudioError:
+            self.has_mute = False
+
         self.fdict = {
             "card": self.alsamixer.cardname(),
             "mixer": self.mixer,
@@ -46,7 +52,10 @@ class ALSA(IntervalModule):
     def run(self):
         self.create_mixer()
 
-        muted = self.alsamixer.getmute()[self.channel] == 1
+        muted = False
+        if self.has_mute:
+            muted = self.alsamixer.getmute()[self.channel] == 1
+        
         self.fdict["volume"] = self.alsamixer.getvolume()[self.channel]
         self.fdict["muted"] = self.muted if muted else self.muted
 
@@ -57,4 +66,4 @@ class ALSA(IntervalModule):
 
     def on_leftclick(self):
         import subprocess
-        subprocess.Popen(["kmix"])
\ No newline at end of file
+        subprocess.Popen(["kmix"])
