@@ -5,9 +5,11 @@ from i3pystatus import IntervalModule
 
 class RunWatch(IntervalModule):
     """
-    Expands the given path using glob to a pidfile and checks if the process ID found inside is valid
+    Expands the given path using glob to a pidfile and checks
+    if the process ID found inside is valid
     (that is, if the process is running).
-    You can use this to check if a specific application, such as a VPN client or your DHCP client is running.
+    You can use this to check if a specific application, 
+    such as a VPN client or your DHCP client is running.
 
     Available formatters are {pid} and {name}.
     """
